import { FASTElement } from "@microsoft/fast-element";
import { StartEnd } from "../patterns/start-end.js";
import type { StartEndOptions } from "../patterns/start-end.js";
/**
 * Breadcrumb configuration options
 * @public
 */
export type BreadcrumbOptions = StartEndOptions;
/**
 * A Breadcrumb Custom HTML Element.
 *
 * @slot start - Content which can be provided before the breadcrumbs
 * @slot end - Content which can be provided after the breadcrumbs
 * @slot - The default slot for the breadcrumb items
 * @csspart list - The element wrapping the slotted items
 *
 * @public
 */
export declare class FASTBreadcrumb extends FASTElement {
    /**
     * @internal
     */
    slottedBreadcrumbItems: HTMLElement[];
    protected slottedBreadcrumbItemsChanged(): void;
    private setItemSeparator;
    /**
     * Finds anchor childnodes in the light DOM or shadow DOM.
     * We look in the shadow DOM because we use an anchor inside the breadcrumb-item template.
     */
    private findChildAnchor;
    /**
     * Sets ARIA Current for the "current" node
     * `aria-current` is not optional and should be set regardless of the href value of a given anchor
     */
    private setAriaCurrent;
}
/**
 * Mark internal because exporting class and interface of the same name
 * confuses API documenter.
 * TODO: https://github.com/microsoft/fast/issues/3317
 * @internal
 */
export interface FASTBreadcrumb extends StartEnd {
}
